@@ -53,8 +53,9 @@ from .models.summary_statistics import (
 from .models.branch import BranchName
 from .models.checks import Check, CheckCreationRequest, CheckId
 from .models.cluster import Cluster, ClusterId, ClusterName
-from .models.commit import (
-    Commit, CommitId, EntityCreatedUpdated, EntityMappingCreatedUpdated, EntityPopulationCreatedUpdated,
+from .models.commit import Commit, CommitId
+from .models.created_updated import (
+    EntityCreatedUpdated, EntityMappingCreatedUpdated, EntityPopulationCreatedUpdated,
     FeatureCreatedUpdated, FeatureSetCreatedUpdated, TemplateCreatedUpdated, TableCreatedUpdated
 )
 from .models.destination import (
